@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Open::This;
 
-our $VERSION = '0.000006';
+our $VERSION = '0.000007';
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(parse_text to_editor_args);
@@ -94,7 +94,13 @@ sub _maybe_extract_line_number {
 
     # git-grep (don't match on ::)
     # lib/Open/This.pm:17
-    if ( $$text =~ s{(\w):{1}(\d*)\b}{$1} ) {
+    if ( $$text =~ s{(\w):(\d*)\b}{$1} ) {
+        return $2;
+    }
+
+    # git-grep contextual match
+    # lib/Open/This.pm-17-
+    if ( $$text =~ s{(\w)-(\d*)-}{$1} ) {
         return $2;
     }
     return undef;
@@ -141,7 +147,7 @@ Open::This - Try to Do the Right Thing when opening files
 
 =head1 VERSION
 
-version 0.000006
+version 0.000007
 
 =head1 DESCRIPTION
 
